@@ -139,7 +139,10 @@ class Script:
         self._lastCommandWasStructNav = False
 
         msg = f'SCRIPT: {self.name} initialized'
-        debug.println(debug.LEVEL_INFO, msg, True)
+        debug.printMessage(debug.LEVEL_INFO, msg, True)
+
+    def __str__(self):
+        return f"{self.name}"
 
     def getListeners(self):
         """Sets up the AT-SPI event listeners for this script.
@@ -318,15 +321,6 @@ class Script:
 
         _eventManager.deregisterScriptListeners(self)
 
-    # [[[WDW - There is a circular reference going on somewhere (see
-    # bug 333168).  In the presence of this reference, the existence
-    # of a __del__ method prevents the garbage collector from
-    # collecting this object. So, we will not define a __del__ method
-    # until we understand where the circular reference is coming from.
-    #
-    #def __del__(self):
-    #    debug.println(debug.LEVEL_FINE, "DELETE SCRIPT: %s" % self.name)
-
     def processObjectEvent(self, event):
         """Processes all AT-SPI object events of interest to this
         script.  The interest in events is specified via the
@@ -343,7 +337,7 @@ class Script:
         role = AXObject.get_role(event.source)
         if role == Atspi.Role.INVALID:
             msg = 'ERROR: Not processing object event for invalid object'
-            debug.println(debug.LEVEL_INFO, msg, True)
+            debug.printMessage(debug.LEVEL_INFO, msg, True)
             return
 
         # Check to see if we really want to process this event.
@@ -399,18 +393,13 @@ class Script:
             return None
 
         if any_data is not None and any_data != cachedEvent.any_data:
-            msg = "SCRIPT: Queued event's any_data (%s) doesn't match %s" \
-                % (cachedEvent.any_data, any_data)
-            debug.println(debug.LEVEL_INFO, msg, True)
+            tokens = ["SCRIPT: Queued event's any_data (",
+                      cachedEvent.any_data, ") doesn't match", any_data]
+            debug.printTokens(debug.LEVEL_INFO, tokens, True)
             return None
 
-        msg = "SCRIPT: Found matching queued event: %s (%s,%s,%s) on %s" \
-            % (cachedEvent.type,
-               cachedEvent.detail1,
-               cachedEvent.detail2,
-               cachedEvent.any_data,
-               cachedEvent.source)
-        debug.println(debug.LEVEL_INFO, msg, True)
+        tokens = ["SCRIPT: Found matching queued event:", cachedEvent]
+        debug.printTokens(debug.LEVEL_INFO, tokens, True)
         return cachedEvent
 
     def skipObjectEvent(self, event):
@@ -453,9 +442,8 @@ class Script:
             reason = "appears to be duplicate state-changed event"
 
         if skip:
-            eventDetails = '        %s' % str(cachedEvent).replace('\t', ' ' * 8)
-            msg = f'SCRIPT: Skipping object event due to {reason}\n{eventDetails}'
-            debug.println(debug.LEVEL_INFO, msg, True)
+            tokens = ["SCRIPT: Skipping object event:", reason, cachedEvent]
+            debug.printTokens(debug.LEVEL_INFO, tokens, True)
 
         return skip
 
