@@ -25,13 +25,12 @@ __date__      = "$Date$"
 __copyright__ = "Copyright (c) 2013-2014 Igalia, S.L."
 __license__   = "LGPL"
 
-import pyatspi
-import time
-
 import orca.debug as debug
 import orca.orca as orca
 import orca.orca_state as orca_state
 import orca.scripts.default as default
+from orca.ax_object import AXObject
+from orca.ax_utilities import AXUtilities
 
 from .script_utilities import Utilities
 
@@ -50,8 +49,7 @@ class Script(default.Script):
             window = self.utilities.topLevelObject(newFocus)
             windowChanged = window and orca_state.activeWindow != window
             if windowChanged:
-                orca_state.activeWindow = window
-                self.windowActivateTime = time.time()
+                orca.setActiveWindow(window)
 
         super().locusOfFocusChanged(event, oldFocus, newFocus)
 
@@ -63,7 +61,7 @@ class Script(default.Script):
             return
 
         msg = "GAIL: locusOfFocus believed to be typeahead. Presenting change."
-        debug.println(debug.LEVEL_INFO, msg, True)
+        debug.printMessage(debug.LEVEL_INFO, msg, True)
         self.presentObject(event.any_data, interrupt=True)
 
     def onFocus(self, event):
@@ -76,20 +74,20 @@ class Script(default.Script):
             return
 
         if self.utilities.isTypeahead(orca_state.locusOfFocus) \
-           and "Table" in pyatspi.listInterfaces(event.source) \
-           and not event.source.getState().contains(pyatspi.STATE_FOCUSED):
+           and AXObject.supports_table(event.source) \
+           and not AXUtilities.is_focused(event.source):
             return
 
-        ancestor = pyatspi.findAncestor(orca_state.locusOfFocus, lambda x: x == event.source)
+        ancestor = AXObject.find_ancestor(orca_state.locusOfFocus, lambda x: x == event.source)
         if not ancestor:
             orca.setLocusOfFocus(event, event.source)
             return
 
-        if ancestor and "Table" in pyatspi.listInterfaces(ancestor):
+        if AXObject.supports_table(ancestor):
             return
 
-        isMenu = lambda x: x and x.getRole() == pyatspi.ROLE_MENU
-        if isMenu(ancestor) and not pyatspi.findAncestor(ancestor, isMenu):
+        if AXUtilities.is_menu(ancestor) \
+           and not AXObject.find_ancestor(ancestor, AXUtilities.is_menu):
             return
 
         orca.setLocusOfFocus(event, event.source)
@@ -97,12 +95,10 @@ class Script(default.Script):
     def onSelectionChanged(self, event):
         """Callback for object:selection-changed accessibility events."""
 
-        isFocused = event.source.getState().contains(pyatspi.STATE_FOCUSED)
-        role = event.source.getRole()
-
+        isFocused = AXUtilities.is_focused(event.source)
         if not isFocused and self.utilities.isTypeahead(orca_state.locusOfFocus):
             msg = "GAIL: locusOfFocus believed to be typeahead. Presenting change."
-            debug.println(debug.LEVEL_INFO, msg, True)
+            debug.printMessage(debug.LEVEL_INFO, msg, True)
 
             selectedChildren = self.utilities.selectedChildren(event.source)
             for child in selectedChildren:
@@ -110,7 +106,7 @@ class Script(default.Script):
                     self.presentObject(child)
             return
 
-        if role == pyatspi.ROLE_LAYERED_PANE \
+        if AXUtilities.is_layered_pane(event.source) \
            and self.utilities.selectedChildCount(event.source) > 1:
             return
 
